Enum Component
Source pub enum Component<'a> {
Scheme(&'a str),
Authority {
userinfo: Option<&'a str>,
host: &'a str,
port: Option<&'a str>,
},
RootSegment,
Segment(&'a str),
Query(&'a str),
Fragment(&'a str),
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.