URIStr

Struct URIStr 

pub struct URIStr { /* private fields */ }
A subtype of str that has been validated as a URI.

Implementations

Source

impl URIStr

pub fn resolve(&self, reference: &Self) -> URIString

Resolve the relative reference reference using self as the base URI.

self must be convertible to an absolute URI through fragment removal and normalization.

Reference
pub fn as_escaped_str(&self) -> &str

Return the escaped URI string.

pub fn as_unescaped_str(&self) -> Option<Cow<'_, str>>

Return the unescaped URI string.

If unescaping fails, return None.

pub fn is_absolute(&self) -> bool

Check if this URI reference is the absolute URI.

Reference

4.3. Absolute URI

pub fn is_relative(&self) -> bool

Check if this URI reference is the relative reference.

Reference

4.2. Relative Reference

pub fn scheme(&self) -> Option<&str>

“scheme” part.

Reference

3.1. Scheme

pub fn authority(&self) -> Option<&str>

“authority” part.

Reference

3.2. Authority

pub fn userinfo(&self) -> Option<&str>

“userinfo” part.

Reference

3.2.1. User Information

pub fn host(&self) -> Option<&str>

“host” part.

Reference

3.2.2. Host

pub fn port(&self) -> Option<&str>

“port” part.

Reference

3.2.3. Port

pub fn path(&self) -> &str

“path” part.

Reference

3.3. Path

pub fn query(&self) -> Option<&str>

“query” part.

Reference

3.4. Query

pub fn fragment(&self) -> Option<&str>

“fragment” part.

Reference

3.5. Fragment

pub fn components(&self) -> Components<'_>

Return an iterator that scans the URI components.