pub struct URIString { /* private fields */ }Implementations
Sourceimpl URIString
impl URIString
pub fn parse(uri: impl AsRef<str>) -> Result<Self, ParseRIError>
Sourcepub fn parse_file_path(path: impl AsRef<Path>) -> Result<Self, ParseRIError>
pub fn parse_file_path(path: impl AsRef<Path>) -> Result<Self, ParseRIError>
Note
In the current implementation, paths that cannot be converted to UTF-8 strings
cannot be handled.
I don’t think there will be any problems in most environments, but there may be
some paths that cannot be handled.
pub fn into_boxed_uri_str(self) -> Box<URIStr>
Methods from Deref<Target = URIStr>
pub fn as_escaped_str(&self) -> &str
pub fn as_unescaped_str(&self) -> Option<Cow<'_, str>>
Sourcepub fn is_absolute(&self) -> bool
pub fn is_absolute(&self) -> bool
Reference
Sourcepub fn is_relative(&self) -> bool
pub fn is_relative(&self) -> bool
Reference
pub fn scheme(&self) -> Option<&str>
pub fn userinfo(&self) -> Option<&str>
pub fn host(&self) -> Option<&str>
pub fn port(&self) -> Option<&str>
pub fn path(&self) -> &str
pub fn query(&self) -> Option<&str>
pub fn fragment(&self) -> Option<&str>
pub fn components(&self) -> Components<'_> ⓘ